@@ -83,6 +83,8 @@ def augments(cls_cpp: Type[Any]):
 
     def class_augment(cls, cls_cpp=cls_cpp):
         for name, member in inspect.getmembers(cls):
+            if hasattr(cls_cpp, name):  # For PyPy: don't replace existing methods
+                continue
             if inspect.isfunction(member):
                 member.__qualname__ = member.__qualname__.replace(
                     cls.__name__, cls_cpp.__name__
@@ -416,14 +418,8 @@ class Extend_Pdf:
         """
         Create a new pikepdf.Stream object that is attached to this PDF.
 
-        Args:
-            data (bytes): Binary data for the stream object
-            d: Dictionary portion of the stream object
-            kwargs: Keyword arguments to define the dictionary. Do not set
-                /Filter or /Length here as pikepdf will manage these.
-
-        Example:
-            pdf.make_stream(b"Binary data here", Type=Name.XObject, Subtype=Name.Image)
+        See:
+            :meth:`pikepdf.Stream.__new__`
 
         """
         return Stream(self, data, d, **kwargs)
@@ -654,7 +650,7 @@ class Extend_Pdf:
             self.Root.PageMode = Name.UseAttachments
 
     def save(
-        self,
+        self,  # TODO mandatory kwargs
         filename_or_stream: Union[Path, str, BinaryIO, None] = None,
         static_id: bool = False,
         preserve_pdfa: bool = True,
@@ -669,6 +665,7 @@ class Extend_Pdf:
         qdf: bool = False,
         progress: Callable[[int], None] = None,
         encryption: Optional[Union[Encryption, bool]] = None,
+        recompress_flate: bool = False,
     ) -> None:
         """
         Save all modifications to this :class:`pikepdf.Pdf`.
@@ -728,6 +725,12 @@ class Extend_Pdf:
                 to encode stream objects. See documentation for
                 ``StreamDecodeLevel``.
 
+            recompress_flate: When disabled (the default), qpdf does not
+                uncompress and recompress streams compressed with the Flate
+                compression algorithm. If True, pikepdf will instruct qpdf to
+                do this, which may be useful if recompressing streams to a
+                higher compression level.
+
             normalize_content: Enables parsing and reformatting the
                 content stream within PDFs. This may debugging PDFs easier.
 
@@ -795,10 +798,11 @@ class Extend_Pdf:
             progress=progress,
             encryption=encryption,
             samefile_check=getattr(self, '_tmp_stream', None) is None,
+            recompress_flate=recompress_flate,
         )
 
     @staticmethod
-    def open(
+    def open(  # TODO mandatory kwargs
         filename_or_stream: Union[Path, str, BinaryIO],
         password: Union[str, bytes] = "",
         hex_password: bool = False,
@@ -889,6 +893,16 @@ class Extend_Pdf:
                 usable.
             FileNotFoundError: If the file was not found.
         """
+        if isinstance(filename_or_stream, bytes) and filename_or_stream.startswith(
+            b'%PDF-'
+        ):
+            warn(
+                "It looks like you called with Pdf.open(data) with a bytes-like object "
+                "containing a PDF. This will probably fail because this function "
+                "expects a filename or opened file-like object. Instead, please use "
+                "Pdf.open(BytesIO(data))."
+            )
+
         tmp_stream, original_filename = None, False
         if allow_overwriting_input:
             try:
@@ -1019,7 +1033,7 @@ class Extend_Page:
             The name of the object.
 
         Example:
-            resource_name = Page(pdf.pages[0]).add_resource(formxobj, Name.XObject)
+            >>> resource_name = Page(pdf.pages[0]).add_resource(formxobj, Name.XObject)
         """
         if not Name.Resources in self.obj:
             self.obj.Resources = Dictionary()
