@@ -36,7 +36,6 @@ from pikepdf import _qpdf as qpdf
 # pylint: disable=eval-used, redefined-outer-name
 
 encode = qpdf._encode
-roundtrip = qpdf._roundtrip
 
 
 def test_none():
@@ -189,6 +188,8 @@ def test_bytes():
     assert str(qs) == s
 
     assert Name('/xyz') == b'/xyz'
+    with pytest.raises(TypeError, match='should be str'):
+        Name(b'/bytes')
 
 
 def test_len_array():
@@ -284,6 +285,7 @@ class TestRepr:
                 '/Array': Array([1, 2, 3.14]),
                 '/Operator': Operator('q'),
                 '/Dictionary': Dictionary({'/Color': 'Red'}),
+                '/None': None,
             }
         )
         if LooseVersion(pikepdf.__libqpdf_version__) >= LooseVersion('10.2.0'):
@@ -299,6 +301,7 @@ class TestRepr:
                     "/Color": "Red"
                 },
                 "/Integer": 42,
+                "/None": None,
                 "/Operator": pikepdf.Operator("q"),
                 "/Real": Decimal('42.42'),
                 "/String": "hi"
@@ -326,9 +329,16 @@ class TestRepr:
             assert eval(repr(s)) == s
 
     def test_repr_indirect(self, resources):
-        graph = pikepdf.open(resources / 'graph.pdf')
-        repr_page0 = repr(graph.pages[0])
-        assert repr_page0[0] == '<', 'should not be constructible'
+        with pikepdf.open(resources / 'graph.pdf') as graph:
+            repr_page0 = repr(graph.pages[0])
+            assert repr_page0[0] == '<', 'should not be constructible'
+
+    def test_repr_circular(self):
+        with pikepdf.new() as pdf:
+            pdf.Root.Circular = pdf.make_indirect(Dictionary())
+            pdf.Root.Circular.Parent = pdf.make_indirect(Dictionary())
+            pdf.Root.Circular.Parent = pdf.make_indirect(pdf.Root.Circular)
+            assert '.get_object' in repr(pdf.Root.Circular)
 
 
 def test_utf16_error():
