@@ -430,7 +430,80 @@ def test_page_index_foreign_page(fourpages, sandwich):
         (Dictionary(S=Name.R, St=42), 'XLII'),
         (Dictionary(S=Name.r, St=1729), 'mdccxxix'),
         (Dictionary(P="Appendix-", S=Name.a, St=261), 'Appendix-ja'),
+        (42, '42'),
+        (Dictionary(S=Name.R, St=-42), ValueError),
+        (Dictionary(S=Name.A, St=-42), ValueError),
     ],
 )
 def test_page_label_dicts(d, result):
-    assert label_from_label_dict(d) == result
+    if isinstance(result, type) and issubclass(result, Exception):
+        with pytest.raises(result):
+            label_from_label_dict(d)
+    else:
+        assert label_from_label_dict(d) == result
+
+
+def test_externalize(resources):
+    with Pdf.open(resources / 'image-mono-inline.pdf') as p:
+        page = Page(p.pages[0])
+        page.contents_coalesce()
+        assert b'BI' in page.obj.Contents.read_bytes(), "no inline image"
+
+        assert Name.XObject not in page.obj.Resources, "expected no xobjs"
+        page.externalize_inline_images()
+
+        assert Name.XObject in page.obj.Resources, "image not created"
+
+        pdfimagexobj = next(iter(p.pages[0].images.values()))
+        assert pdfimagexobj.Subtype == Name.Image
+
+        assert page.label == '1'
+
+
+def test_page_labels():
+    p = Pdf.new()
+    d = Dictionary(Type=Name.Page, MediaBox=[0, 0, 612, 792], Resources=Dictionary())
+    for n in range(5):
+        p.pages.append(d)
+        p.pages[n].Contents = Stream(p, b"BT (Page %s) Tj ET" % str(n).encode())
+
+    p.Root.PageLabels = p.make_indirect(
+        Dictionary(
+            Nums=Array(
+                [
+                    0,  # new label rules begin at index 0
+                    Dictionary(S=Name.r),  # use lowercase roman numerals, until...
+                    2,  # new label rules begin at index 2
+                    Dictionary(
+                        S=Name.D, St=42, P='Prefix-'
+                    ),  # label pages as 'Prefix-42', 'Prefix-43', ...
+                ]
+            )
+        )
+    )
+
+    labels = ['i', 'ii', 'Prefix-42', 'Prefix-43', 'Prefix-44']
+    for n in range(5):
+        rawpage = p.pages[n]
+        page = Page(rawpage)
+        assert page.label == labels[n]
+
+
+def test_unattached_page():
+    rawpage = Dictionary(
+        Type=Name.Page, MediaBox=[0, 0, 612, 792], Resources=Dictionary()
+    )
+    page = Page(rawpage)
+
+    with pytest.raises(ValueError, match='not attached'):
+        page.index
+    with pytest.raises(ValueError, match='not attached'):
+        page.label
+
+
+def test_unindexed_page(graph):
+    rawpage = graph.pages[0]
+    page = Page(rawpage)
+    del graph.pages[0]
+    with pytest.raises(ValueError, match='not consistently registered'):
+        page.index
