@@ -21,9 +21,10 @@ from pikepdf import PasswordError, Pdf, PdfError, Stream
 
 @pytest.fixture
 def trivial(resources):
-    return Pdf.open(
+    with Pdf.open(
         resources / 'pal-1bit-trivial.pdf', access_mode=pikepdf.AccessMode.mmap
-    )
+    ) as pdf:
+        yield pdf
 
 
 def test_new(outdir):
@@ -96,6 +97,10 @@ class TestPasswords:
         with pytest.raises(PasswordError):
             Pdf.open(resources / 'graph-encrypted.pdf')
 
+    def test_open_pdf_user_password(self, resources):
+        with Pdf.open(resources / 'graph-encrypted.pdf', password='user'):
+            pass
+
 
 class TestPermissions:
     def test_some_permissions_missing(self, resources):
@@ -148,8 +153,9 @@ class TestStreams:
 class TestMemory:
     def test_memory(self, resources):
         pdf = (resources / 'pal-1bit-trivial.pdf').read_bytes()
-        with pytest.raises(Exception):
-            pdf = Pdf.open(pdf)
+        with pytest.warns(UserWarning, match="bytes-like object containing a PDF"):
+            with pytest.raises(Exception):
+                pdf = Pdf.open(pdf)
 
 
 def test_remove_unreferenced(resources, outdir):
@@ -179,8 +185,8 @@ def test_progress(trivial, outdir):
 
 @pytest.mark.skipif(locale.getpreferredencoding() != 'UTF-8', reason="Unicode check")
 def test_unicode_filename(resources, outdir):
-    target1 = outdir / '测试.pdf'
-    target2 = outdir / '通过考试.pdf'
+    target1 = outdir / '测试.pdf'  # Chinese: test.pdf
+    target2 = outdir / '通过考试.pdf'  # Chinese: pass the test.pdf
     shutil.copy(fspath(resources / 'pal-1bit-trivial.pdf'), fspath(target1))
     with Pdf.open(target1) as pdf:
         pdf.save(target2)
@@ -270,7 +276,7 @@ def test_allow_overwriting_input(resources, tmp_path):
             assert 'dc:title' not in meta
 
 
-def test_allow_overwriting_input_ko(resources):
+def test_allow_overwriting_input_without_filename():
     with pytest.raises(ValueError):
         with pikepdf.open(BytesIO(), allow_overwriting_input=True):
             pass
